@@ -3,7 +3,12 @@
 import boost_histogram.axis as _axis
 import boost_histogram.storage as _storage
 
-from dask_histogram.core import AggHistogram, PartitionedHistogram, factory
+from dask_histogram.core import (
+    AggHistogram,
+    PartitionedHistogram,
+    factory,
+    partitioned_factory,
+)
 from dask_histogram.routines import histogram, histogram2d, histogramdd
 from dask_histogram.version import __version__
 
@@ -27,5 +32,6 @@ __all__ = (
     "histogram",
     "histogram2d",
     "histogramdd",
+    "partitioned_factory",
     "storage",
 )
